======================
Demos and Other Topics
======================

*  :ref:`correlation`
*  `Airline groupby demo <http://nbviewer.ipython.org/github/Paradigm4/SciDB-py/blob/master/examples/airline_groupby.ipynb>`_

